==> zio-aws-timestreamwrite_2.13-5.17.160.1-sources.jar: zio/aws/timestreamwrite/model/CreateTableResponse.scala <==
package zio.aws.timestreamwrite.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateTableResponse(
    table: Option[zio.aws.timestreamwrite.model.Table] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamwrite.model.CreateTableResponse = {
    import CreateTableResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamwrite.model.CreateTableResponse
      .builder()
      .optionallyWith(table.map(value => value.buildAwsValue()))(_.table)
      .build()
  }
  def asReadOnly: zio.aws.timestreamwrite.model.CreateTableResponse.ReadOnly =
    zio.aws.timestreamwrite.model.CreateTableResponse.wrap(buildAwsValue())
}
object CreateTableResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamwrite.model.CreateTableResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamwrite.model.CreateTableResponse =
      zio.aws.timestreamwrite.model
        .CreateTableResponse(table.map(value => value.asEditable))
    def table: Option[zio.aws.timestreamwrite.model.Table.ReadOnly]
    def getTable
        : ZIO[Any, AwsError, zio.aws.timestreamwrite.model.Table.ReadOnly] =
      AwsError.unwrapOptionField("table", table)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamwrite.model.CreateTableResponse
  ) extends zio.aws.timestreamwrite.model.CreateTableResponse.ReadOnly {
    override val table: Option[zio.aws.timestreamwrite.model.Table.ReadOnly] =
      scala
        .Option(impl.table())
        .map(value => zio.aws.timestreamwrite.model.Table.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamwrite.model.CreateTableResponse
  ): zio.aws.timestreamwrite.model.CreateTableResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-timestreamwrite_2.13-5.17.267.6-sources.jar: zio/aws/timestreamwrite/model/CreateTableResponse.scala <==
package zio.aws.timestreamwrite.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateTableResponse(
    table: Optional[zio.aws.timestreamwrite.model.Table] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.timestreamwrite.model.CreateTableResponse = {
    import CreateTableResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.timestreamwrite.model.CreateTableResponse
      .builder()
      .optionallyWith(table.map(value => value.buildAwsValue()))(_.table)
      .build()
  }
  def asReadOnly: zio.aws.timestreamwrite.model.CreateTableResponse.ReadOnly =
    zio.aws.timestreamwrite.model.CreateTableResponse.wrap(buildAwsValue())
}
object CreateTableResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.timestreamwrite.model.CreateTableResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.timestreamwrite.model.CreateTableResponse =
      zio.aws.timestreamwrite.model
        .CreateTableResponse(table.map(value => value.asEditable))
    def table: Optional[zio.aws.timestreamwrite.model.Table.ReadOnly]
    def getTable
        : ZIO[Any, AwsError, zio.aws.timestreamwrite.model.Table.ReadOnly] =
      AwsError.unwrapOptionField("table", table)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.timestreamwrite.model.CreateTableResponse
  ) extends zio.aws.timestreamwrite.model.CreateTableResponse.ReadOnly {
    override val table: Optional[zio.aws.timestreamwrite.model.Table.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.table())
        .map(value => zio.aws.timestreamwrite.model.Table.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.timestreamwrite.model.CreateTableResponse
  ): zio.aws.timestreamwrite.model.CreateTableResponse.ReadOnly = new Wrapper(
    impl
  )
}
